using System.Web.UI.WebControls;
using NUnit.Framework;
using Rhino.Mocks;

namespace Lists.Web.Controls.Test
{
    [TestFixture]
    public class WebLookupListTest
    {
        private const string TEXT = "JP";
        private const string VALUE = "1";
        private MockRepository mockery;

        ListControl dropDownList;
        ILookupList lookupList;

        [SetUp]
        public void Setup()
        {
            mockery = new MockRepository();
            
            dropDownList = new DropDownList();
            lookupList = new WebLookupList(dropDownList);
        }

        [TearDown]
        public void TearDown()
        {
            mockery.VerifyAll();
        }

        [Test]
        public void ShouldAddItemToUnderlyingList()
        {

            ILookupDTO mockDTO = mockery.CreateMock<ILookupDTO>();
            Expect.Call(mockDTO.Text).Return(TEXT);
            Expect.Call(mockDTO.Value).Return(VALUE);
            
            mockery.ReplayAll();

            lookupList.Add(mockDTO);
            
            Assert.AreEqual(1,dropDownList.Items.Count);
            Assert.AreEqual(TEXT,dropDownList.Items[0].Text);
            Assert.AreEqual(VALUE,dropDownList.Items[0].Value);
            
        }

        [Test]
        public void ShouldClearUnderlyingList()
        {
            dropDownList.Items.Add(new ListItem("JP","JP"));
            lookupList.Clear();
            
            Assert.AreEqual(0,dropDownList.Items.Count);
        }
    }
}